@@ -1,17 +1,24 @@
-# $Id: Senna.pm 14 2005-05-31 05:00:21Z daisuke $
+# $Id: Senna.pm 37 2005-08-02 12:04:23Z daisuke $
 #
 # Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
 
 package Senna;
-use 5.006001;
 use strict;
-our $VERSION = '0.02';
+use vars qw($VERSION);
 
-require XSLoader;
-XSLoader::load('Senna', $VERSION);
-
-Senna::sen_init();
+BEGIN
+{
+    $VERSION = '0.07';
+    if ($] > 5.006) {
+        require XSLoader;
+        XSLoader::load('Senna', $VERSION);
+    } else {
+        require DynaLoader;
+        @Senna::ISA = ('DynaLoader');
+        __PACKAGE__->bootstrap();
+    }
+}
 
 use Senna::Index;
 use Senna::Cursor;
@@ -23,7 +30,7 @@ __END__
 
 =head1 NAME
 
-Senna - Perl Interrface To Senna Fulltext Search Engine
+Senna - Perl Interface To Senna Fulltext Search Engine
 
 =head1 SYNOPSIS
 
@@ -45,10 +52,10 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
-Development funded by Brazil Ltd. E<lt>http://dev.razil.jp/projects/senna/E<gt>
+Development funded by Brazil Ltd. E<lt>http://dev.razil.jp/project/senna/E<gt>
 
 =head1 SEE ALSO
 
-http://dev.razil.jp/projects/senna - Senna Development Homepage
+http://dev.razil.jp/project/senna - Senna Development Homepage
 
 =cut
