@@ -1,4 +1,4 @@
-# $Id: Cursor.pm 9 2005-05-30 06:43:26Z daisuke $
+# $Id: Cursor.pm 35 2005-07-25 02:02:35Z daisuke $
 #
 # Daisuke Maki <dmak@cpan.org>
 # All rights reserved.
@@ -9,14 +9,6 @@ use Senna::Result;
 use vars qw($VERSION);
 $VERSION = '0.01';
 
-sub new
-{
-    my $class = shift;
-    my $self  = bless {}, $class;
-    $self->_alloc_cursor_state();
-    return $self;
-}
-
 __END__
 
 =head1 NAME
@@ -37,4 +29,18 @@ Senna::Cursor - A Senna Cursor Object
   $cursor->rewind();
   $cursor->close();
 
+=head1 AUTHOR
+
+Copyright (C) 2005 by Daisuke Maki <dmaki@cpan.org>
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.6 or,
+at your option, any later version of Perl 5 you may have available.
+
+Development funded by Brazil Ltd. E<lt>http://dev.razil.jp/project/senna/E<gt>
+
+=head1 SEE ALSO
+
+http://dev.razil.jp/project/senna - Senna Development Homepage
+
 =cut
